@@ -74,17 +74,6 @@ Please specify something like '?charset=utf8' explicitly.""")
         return ref_table
 
 
-    @staticmethod
-    def one_to_one(ref_model, ref_name = None, backref_name = None):
-        """Add a one-to-one relationship between two models.
-        This method is a shortcut to the method Database.foreign_key(ref_model, ref_name, backref_name, True)
-        """
-        import warnings
-        warnings.warn("one_to_one is deprecated, will be removed in version 0.3. Please use foreign_key(one_to_one = True) instead.", DeprecationWarning)
-
-        return Database.foreign_key(ref_model, ref_name, backref_name, True)
-
-
     @staticmethod
     def many_to_many(ref_model, ref_name = None, backref_name = None, middle_table_name = None):
         """Class Decorator, add a many-to-many relationship between two SQLAlchemy models.
@@ -117,6 +106,15 @@ Please specify something like '?charset=utf8' explicitly.""")
                 Column(right_column_name, Integer, ForeignKey('{0}.id'.format(ref_table_name)), primary_key = True),
             )
 
+            middle_model = type(my_middle_table_name, (Database.BaseModel,), dict(__table__ = middle_table))
+            setattr(middle_model, 'left', relationship(cls.__name__, 
+                primaryjoin = '{0}.{1} == {2}.id'.format(middle_model.__name__, left_column_name, cls.__name__),
+                backref = backref(my_middle_table_name + 'left', cascade = 'all')))
+            setattr(middle_model, 'right', relationship(ref_model_name,
+                primaryjoin = '{0}.{1} == {2}.id'.format(middle_model.__name__, right_column_name, ref_model_name), 
+                backref = backref(my_middle_table_name + 'right', cascade = 'all')))
+            #todo: 也许上面的这段很多是不必要的代码. 我想要的仅仅是级联删除而已, 也许在middle_table那里已经可以指定了.
+
             my_backref_name = backref_name or '{0}s'.format(table_name)
             parameters = dict(secondary = middle_table, lazy = 'dynamic', backref = backref(my_backref_name, lazy = 'dynamic'))
             if table_name == ref_table_name:             
